@@ -5,7 +5,7 @@ class Distro(Module):
     '''Set User as sudoer
     kw:
         usr : User name
-        pub : Piblic key
+        pub : Public key
 
     - Create User if not present
     - Add User to sudoers
@@ -19,13 +19,8 @@ class Distro(Module):
 
         distro = target.distro
 
-        if not distro.user(usr).deploy():
-            return False
+        ok = distro.user(usr).deploy()
+        ok = ok and target.deploy('sudoers', user=usr)
+        ok = ok and target.deploy('copy_id', **kw)
 
-        if not target.deploy('sudoers', user=usr):
-            return False
-
-        if not target.deploy('copy_id', **kw):
-            return False
-
-        return True
+        return ok
