@@ -10,6 +10,8 @@ class Distro(Module):
         dst : File's Dest (defaults to "downloaded"
     '''
 
+    register = 'download'
+
     def deploy(self, target, **kw):
         url, dst = kw['url'], kw.get('dst')
         dst = dst or 'downloaded'
@@ -34,6 +36,6 @@ class Distro(Module):
                         msg = err[0]
                         error(msg)
                         raise RuntimeError(msg)
-        target(f'ls -l {dst}')
+        # target(f'ls -l {dst}')
         return True
 
